using System;
using System.Collections.Generic;
using System.ComponentModel;
using System.Data;
using System.Diagnostics;
using System.Drawing;
using System.Text;
using System.Windows.Forms;

using Infragistics.Win;
using Infragistics.Win.UltraWinEditors;
using Infragistics.Win.UltraWinTree;

namespace UltraTreeCustomization
{
    public partial class Form1 : Form
    {
        private const string BANDNAME = "RootBand";
        private const string SOURCECOLNAME = "SourceIntColumn";
        private Bitmap m_Image = SystemIcons.Information.ToBitmap();
        private Bitmap m_DefaultImage = SystemIcons.Question.ToBitmap();
        private UltraComboEditor m_UltraComboEditor;

        public Form1()
        {
            InitializeComponent();
        }

        private void OnFormLoad(object sender, EventArgs e)
        {
            // Assign the datasource to the tree here so that columnsets aren't
            // recorded at design-time, which pre-empts the ColumnSetGenerated event.
            this.m_UltraTree.DataSource = this.m_UltraDataSource;
            this.m_UltraTree.DataMember = this.m_UltraDataSource.Band.Key;
        }

        private void OnColumnSetGenerated(object sender, ColumnSetGeneratedEventArgs e)
        {
            switch (e.ColumnSet.Key)
            {
                case BANDNAME:
                    // Allow editing of cell by dropdown listbox of images.
                    e.ColumnSet.AllowCellEdit = AllowCellEdit.Full;

                    UltraTreeNodeColumn node = e.ColumnSet.Columns[SOURCECOLNAME];
                    m_UltraComboEditor = new UltraComboEditor();

                    //
                    // Customize node appearance and behavior.
                    //

                    // Set in-place editor. The editor items will be integers with
                    // appearances that cause them to be displayed as images.
                    //
                    // Problem:
                    // The initial display and dropdown list are correct.
                    // The cell value disappears when the dropdown list opens up, 
                    // and stays empty until loss of focus.
                    node.EditorControl = m_UltraComboEditor;

                    // Set caption to space so it becomes invisible.
                    node.Text = " ";

                    // Set comfortable width for image and center it.
                    node.LayoutInfo.MinimumCellSize = 
                        new Size(50, node.LayoutInfo.MinimumCellSize.Height);
                    node.CellAppearance.ImageHAlign = HAlign.Center;

                    // Header displayed as image, not text
                    node.HeaderAppearance.Image = m_Image;
                    node.HeaderAppearance.ImageHAlign = HAlign.Center;


                    //
                    // Create imagelist. 
                    //
                    // The editor's Item[].Appearance.Image will be an index into this list.
                    //

                    ImageList imageList = new ImageList();
                    imageList.Images.Add(m_DefaultImage);
                    imageList.Images.Add(m_Image);


                    //
                    // Customize editor appearance and behavior.
                    //

                    // Disable entering text.
                    m_UltraComboEditor.DropDownStyle = DropDownStyle.DropDownList;

                    // Set editor's image list (appears to be unused; the imageList 
                    // in the tree gets used).
                    m_UltraComboEditor.ImageList = imageList;

                    // Add value list items.
                    m_UltraComboEditor.Items.Add(0);
                    m_UltraComboEditor.Items.Add(1);

                    // Set each item's appearance to be an image via the imagelist.
                    foreach (ValueListItem item in m_UltraComboEditor.Items)
                    {
                        item.Appearance.Image = (int)(item.DataValue);
                        item.Appearance.ImageHAlign = HAlign.Center;
                        item.ValueList.DisplayStyle = ValueListDisplayStyle.Picture;
                    }


                    //
                    // Customize tree.
                    //

                    // Set the tree's imagelist so resulting cell values are mapped.
                    // Without this, dropdown list does not show images.
                    m_UltraTree.ImageList = imageList;

                    break;
            }
        }
    }
}